@@ -4,6 +4,7 @@ import pytest
 from github import UnknownObjectException
 
 from githubapp import Config
+from githubapp.config import ConfigError
 
 CONFIG_TEST = """
 config1: value1
@@ -32,30 +33,51 @@ def test_config():
     assert Config.config1 == "value1"
     assert Config.config2.subconfig1 == "value2"
     assert Config.config3 == ["value3", "value4"]
-    assert Config.config4 is None
 
 
-def test_is_feature_enables():
+def test_default_values():
     repository = Mock()
     repository.get_contents.return_value = Mock(
         decoded_content="""
-feature1: True
-feature2:
-    attr: x
-feature3: False
+feature3: override_value
 """
     )
+    Config.create_config("feature1", default="default1")
+    Config.create_config("feature2", subfeature1="default2")
     Config.load_config_from_file("file", repository)
 
-    assert Config.is_feature1_enabled
-    assert Config.is_feature2_enabled
-    assert not Config.is_feature3_enabled
-    assert Config.is_feature4_enabled
+    assert Config.feature1 == "default1"
+    assert Config.feature2.subfeature1 == "default2"
+    assert Config.feature3 == "override_value"
 
 
 def test_config_on_file_not_found():
     repository = Mock()
     repository.get_contents.side_effect = UnknownObjectException(404)
     Config.load_config_from_file("file", repository)
+    Config.create_config("config1", default="default1")
 
-    assert Config.config1 is None
+    assert Config.config1 == "default1"
+
+
+def test_no_config_value():
+    repository = Mock()
+    repository.get_contents.return_value = Mock(decoded_content="")
+    Config.load_config_from_file("file", repository)
+
+    with pytest.raises(ConfigError) as err:
+        # noinspection PyStatementEffect
+        Config.config1
+    assert (
+        str(err.value)
+        == "No such config value: config1. And there is no default value for it"
+    )
+
+
+def test_validate_default_or_values():
+    with pytest.raises(ConfigError) as err:
+        Config.create_config("config1", default="value1", value2="value2")
+    assert (
+        str(err.value)
+        == "You cannot set the default value AND default values for sub values"
+    )
